import imageio
from fileformats.image.raster import RasterImage


@RasterImage.read_data.register
def read_raster_data(image: RasterImage):
    return imageio.imread(image.fspath)


@RasterImage.write_data.register
def write_raser_data(image: RasterImage, data_array):
    imageio.imwrite(image.fspath, data_array)



import typing as ty
from pathlib import Path
import pydicom
from fileformats.core import FileSet
from fileformats.application import Dicom
import medimages4tests.dummy.dicom.mri.t1w.siemens.skyra.syngo_d13c
from fileformats.core.utils import SampleFileGenerator


@FileSet.read_metadata.register
def dicom_read_metadata(
    dicom: Dicom, selected_keys: ty.Optional[ty.Sequence[str]] = None
) -> ty.Mapping[str, ty.Any]:
    dcm = pydicom.dcmread(dicom.fspath, specific_tags=selected_keys)
    [getattr(dcm, a, None) for a in dir(dcm)]  # Ensure all keywords are set
    metadata = {
        e.keyword: e.value  # type: ignore[union-attr]
        for e in dcm.elements()
        if getattr(e, "keyword", False) and e.keyword != "PixelData"  # type: ignore[union-attr]
    }
    return metadata


@FileSet.generate_sample_data.register
def dicom_generate_sample_data(
    dicom: Dicom,
    generator: SampleFileGenerator,
) -> ty.Iterable[Path]:
    return next(
        medimages4tests.dummy.dicom.mri.t1w.siemens.skyra.syngo_d13c.get_image(
            out_dir=generator.dest_dir
        ).iterdir()
    )



import sys
import pytest
from imageio.core.fetching import get_remote_file
from fileformats.image import Bitmap, Gif, Jpeg, Png, Tiff


@pytest.fixture(scope="session")
def jpg() -> Jpeg:
    # imageio.imread("imageio:bricks.jpg")
    return Jpeg(get_remote_file("images/bricks.jpg"))


@pytest.fixture(scope="session")
def png() -> Png:
    return Png(get_remote_file("images/chelsea.png"))


@pytest.mark.xfail(
    sys.version_info.minor <= 9,
    reason="upstream Pydra issue with type-checking 'type' objects",
)
def test_jpg_to_gif(jpg):
    Gif.convert(jpg)


@pytest.mark.xfail(
    sys.version_info.minor <= 9,
    reason="upstream Pydra issue with type-checking 'type' objects",
)
def test_png_to_tiff(png):
    Tiff.convert(png)


@pytest.mark.xfail(
    sys.version_info.minor <= 9,
    reason="upstream Pydra issue with type-checking 'type' objects",
)
def test_png_to_bitmap(png):
    Bitmap.convert(png)
